py3createtorrent
================

*Create torrents via command line!*

py3createtorrent is a comprehensive shell/commandline utility for creating torrents (Linux & Windows).

Some of the features:

* you can create **huge torrents** for any amount of data
* you can add a **comment** to the torrent file
* you can create **private torrents** (disabled DHT, ...)
* you can create torrents with **multiple trackers**
* you can create **trackerless torrents** (not yet released, but already implemented in develop branch)
* you can **exclude specific files/folders**
* you can exclude files/folders based on **regular expressions**
* you can specify **custom piece sizes**
* you can specify custom creation dates

Documentation
-------------

Installation, configuration and usage are explained here:
https://py3createtorrent.readthedocs.io/en/latest/user.html
